==> mingw-w64-clang-aarch64-qt6-static-6.6.2-5-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6QuickDialogs2QuickImpl/Qt6QuickDialogs2QuickImplTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::QuickDialogs2QuickImpl" for configuration "Release"
set_property(TARGET Qt6::QuickDialogs2QuickImpl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickDialogs2QuickImpl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6QuickDialogs2QuickImpl.a"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickDialogs2QuickImpl )
list(APPEND _cmake_import_check_files_for_Qt6::QuickDialogs2QuickImpl "${_IMPORT_PREFIX}/lib/libQt6QuickDialogs2QuickImpl.a" )

# Import target "Qt6::QuickDialogs2QuickImpl_resources_1" for configuration "Release"
set_property(TARGET Qt6::QuickDialogs2QuickImpl_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickDialogs2QuickImpl_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Dialogs/quickimpl/objects-Release/QuickDialogs2QuickImpl_resources_1/.rcc/qrc_qmake_QtQuick_Dialogs_quickimpl.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickDialogs2QuickImpl_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickDialogs2QuickImpl_resources_1 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Dialogs/quickimpl/objects-Release/QuickDialogs2QuickImpl_resources_1/.rcc/qrc_qmake_QtQuick_Dialogs_quickimpl.cpp.obj" )

# Import target "Qt6::QuickDialogs2QuickImpl_qmlcache" for configuration "Release"
set_property(TARGET Qt6::QuickDialogs2QuickImpl_qmlcache APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickDialogs2QuickImpl_qmlcache PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Dialogs/quickimpl/objects-Release/QuickDialogs2QuickImpl_qmlcache/.rcc/qmlcache/QuickDialogs2QuickImpl_qmlcache_loader.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickDialogs2QuickImpl_qmlcache )
list(APPEND _cmake_import_check_files_for_Qt6::QuickDialogs2QuickImpl_qmlcache "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Dialogs/quickimpl/objects-Release/QuickDialogs2QuickImpl_qmlcache/.rcc/qmlcache/QuickDialogs2QuickImpl_qmlcache_loader.cpp.obj" )

# Import target "Qt6::QuickDialogs2QuickImpl_resources_2" for configuration "Release"
set_property(TARGET Qt6::QuickDialogs2QuickImpl_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickDialogs2QuickImpl_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Dialogs/quickimpl/objects-Release/QuickDialogs2QuickImpl_resources_2/.rcc/qrc_QuickDialogs2QuickImpl_raw_qml_0.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickDialogs2QuickImpl_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickDialogs2QuickImpl_resources_2 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Dialogs/quickimpl/objects-Release/QuickDialogs2QuickImpl_resources_2/.rcc/qrc_QuickDialogs2QuickImpl_raw_qml_0.cpp.obj" )

# Import target "Qt6::QuickDialogs2QuickImpl_resources_3" for configuration "Release"
set_property(TARGET Qt6::QuickDialogs2QuickImpl_resources_3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickDialogs2QuickImpl_resources_3 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/QuickDialogs2QuickImpl_resources_3/.rcc/qrc_QuickDialogs2QuickImpl.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickDialogs2QuickImpl_resources_3 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickDialogs2QuickImpl_resources_3 "${_IMPORT_PREFIX}/lib/objects-Release/QuickDialogs2QuickImpl_resources_3/.rcc/qrc_QuickDialogs2QuickImpl.cpp.obj" )

# Import target "Qt6::QuickDialogs2QuickImpl_resources_4" for configuration "Release"
set_property(TARGET Qt6::QuickDialogs2QuickImpl_resources_4 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickDialogs2QuickImpl_resources_4 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/QuickDialogs2QuickImpl_resources_4/.rcc/qrc_QuickDialogs2QuickImplShaders.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickDialogs2QuickImpl_resources_4 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickDialogs2QuickImpl_resources_4 "${_IMPORT_PREFIX}/lib/objects-Release/QuickDialogs2QuickImpl_resources_4/.rcc/qrc_QuickDialogs2QuickImplShaders.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-qt6-static-6.7.0-1-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6QuickDialogs2QuickImpl/Qt6QuickDialogs2QuickImplTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::QuickDialogs2QuickImpl" for configuration "Release"
set_property(TARGET Qt6::QuickDialogs2QuickImpl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickDialogs2QuickImpl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6QuickDialogs2QuickImpl.a"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickDialogs2QuickImpl )
list(APPEND _cmake_import_check_files_for_Qt6::QuickDialogs2QuickImpl "${_IMPORT_PREFIX}/lib/libQt6QuickDialogs2QuickImpl.a" )

# Import target "Qt6::QuickDialogs2QuickImpl_resources_1" for configuration "Release"
set_property(TARGET Qt6::QuickDialogs2QuickImpl_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickDialogs2QuickImpl_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Dialogs/quickimpl/objects-Release/QuickDialogs2QuickImpl_resources_1/.rcc/qrc_qmake_QtQuick_Dialogs_quickimpl_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickDialogs2QuickImpl_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickDialogs2QuickImpl_resources_1 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Dialogs/quickimpl/objects-Release/QuickDialogs2QuickImpl_resources_1/.rcc/qrc_qmake_QtQuick_Dialogs_quickimpl_init.cpp.obj" )

# Import target "Qt6::QuickDialogs2QuickImpl_resources_2" for configuration "Release"
set_property(TARGET Qt6::QuickDialogs2QuickImpl_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickDialogs2QuickImpl_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Dialogs/quickimpl/objects-Release/QuickDialogs2QuickImpl_resources_2/.rcc/qrc_QuickDialogs2QuickImpl_raw_qml_0_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickDialogs2QuickImpl_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickDialogs2QuickImpl_resources_2 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/Dialogs/quickimpl/objects-Release/QuickDialogs2QuickImpl_resources_2/.rcc/qrc_QuickDialogs2QuickImpl_raw_qml_0_init.cpp.obj" )

# Import target "Qt6::QuickDialogs2QuickImpl_resources_3" for configuration "Release"
set_property(TARGET Qt6::QuickDialogs2QuickImpl_resources_3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickDialogs2QuickImpl_resources_3 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/QuickDialogs2QuickImpl_resources_3/.rcc/qrc_QuickDialogs2QuickImpl_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickDialogs2QuickImpl_resources_3 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickDialogs2QuickImpl_resources_3 "${_IMPORT_PREFIX}/lib/objects-Release/QuickDialogs2QuickImpl_resources_3/.rcc/qrc_QuickDialogs2QuickImpl_init.cpp.obj" )

# Import target "Qt6::QuickDialogs2QuickImpl_resources_4" for configuration "Release"
set_property(TARGET Qt6::QuickDialogs2QuickImpl_resources_4 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::QuickDialogs2QuickImpl_resources_4 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/QuickDialogs2QuickImpl_resources_4/.rcc/qrc_QuickDialogs2QuickImplShaders_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::QuickDialogs2QuickImpl_resources_4 )
list(APPEND _cmake_import_check_files_for_Qt6::QuickDialogs2QuickImpl_resources_4 "${_IMPORT_PREFIX}/lib/objects-Release/QuickDialogs2QuickImpl_resources_4/.rcc/qrc_QuickDialogs2QuickImplShaders_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
